@@ -1,9 +1,9 @@
 package Dist::Zilla::Plugin::OurPkgVersion;
-use 5.006;
+use 5.008;
 use strict;
 use warnings;
 BEGIN {
-	our $VERSION = '0.2.0'; # VERSION
+	our $VERSION = 'v0.3.0'; # VERSION
 }
 use Moose;
 with (
@@ -40,16 +40,31 @@ sub munge_file {
 
 	my $comments = $doc->find('PPI::Token::Comment');
 
+	my $version_regex
+		= q{
+                  ^
+                  (\s*)           # capture all whitespace before comment
+                  (
+                    \#\s+VERSION  # capture # VERSION
+                    \b            # and ensure it ends on a word boundary
+                    [             # conditionally
+                      [:print:]   # all printable characters after VERSION
+                      \s          # any whitespace including newlines see GH #5
+                    ]*            # as many of the above as there are
+                  )
+                  $               # until the EOL}
+		;
+
 	my $munged_version = 0;
 	if ( ref($comments) eq 'ARRAY' ) {
 		foreach ( @{ $comments } ) {
-			if ( /^(\s*)(\#\s+VERSION\b)$/xms ) {
+			if ( /$version_regex/xms ) {
 				my ( $ws, $comment ) =  ( $1, $2 );
 				my $code
 						= "$ws"
 						. q{our $VERSION = '}
 						. $version
-						. qq{'; $comment\n}
+						. qq{'; $comment}
 						;
 				$_->set_content("$code");
 				$file->content( $doc->serialize );
@@ -83,7 +98,7 @@ Dist::Zilla::Plugin::OurPkgVersion - no line insertion and does Package version
 
 =head1 VERSION
 
-version 0.2.0
+version v0.3.0
 
 =head1 SYNOPSIS
 
@@ -156,6 +171,18 @@ becomes
 	}
 	...
 
+you can also add additional comments to your comment
+
+	...
+	# VERSION: generated by DZP::OurPkgVersion
+	...
+
+becomes
+
+	...
+	our $VERSION = '0.1.0'; # VERSION: generated by DZP::OurPkgVersion
+	...
+
 Also note, the package line is not in any way significant, it will insert the
 C<our $VERSION> line anywhere in the file before C<# VERSION> as many times as
 you've written C<# VERSION> regardless of whether or not inserting it there is
@@ -180,7 +207,7 @@ tells which files to munge, see L<Dist::Zilla::Role::FileMunger>
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-http://github.com/xenoterracide/Dist-Zilla-Plugin-OurPkgVersion/issues
+https://github.com/xenoterracide/Dist-Zilla-Plugin-OurPkgVersion/issues
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
